/*
 * (c) Copyright Adrian Pop, adrpo@ida.liu.se, 2006-02-21
 * All Rights Reserved.
 */
package org.pelab.rml.editor.rml;


import java.util.ArrayList;
import java.util.List;
import org.eclipse.jface.text.rules.*;

/**
 * This scanner recognizes the C Sharp Doc comments and C Sharp multi line comments.
 */
public class RMLPartitionScanner extends RuleBasedPartitionScanner {

	public final static String RML_MULTILINE_COMMENT= "__rml_multiline_comment"; 
	public final static String RML_DOC= "__rml_doc"; 

	/**
	 * Detector for empty comments.
	 */
	static class EmptyCommentDetector implements IWordDetector {

		/* (non-Javadoc)
		* Method declared on IWordDetector
	 	*/
		public boolean isWordStart(char c) {
			return (c == '(');
		}

		/* (non-Javadoc)
		* Method declared on IWordDetector
	 	*/
		public boolean isWordPart(char c) {
			return (c == '*');
		}
	};

	/**
	 * Creates the partitioner and sets up the appropriate rules.
	 */
	public RMLPartitionScanner() {
		super();

		IToken cSharpDoc= new Token(RML_DOC);
		IToken comment= new Token(RML_MULTILINE_COMMENT);

		List rules= new ArrayList();


		// Add rules for multi-line comments 
		rules.add(new MultiLineRule("(*", "*)", comment)); 

		// Add rules for c sharp doc.
		rules.add(new EndOfLineRule("///", cSharpDoc)); 

		// Add rule for single line comments.
		rules.add(new EndOfLineRule("//", Token.UNDEFINED)); 

		// Add rule for strings and character constants.
		rules.add(new SingleLineRule("\"", "\"", Token.UNDEFINED, '\\')); 
		rules.add(new SingleLineRule("'", "'", Token.UNDEFINED, '\\')); 

		// Add special case word rule.
//		WordRule wordRule= new WordRule(new EmptyCommentDetector());
//		wordRule.addWord("/**/", comment); 
		WordPatternRule wordRule= new WordPatternRule(new EmptyCommentDetector(), "(*", "*)", comment); 
		rules.add(wordRule);
		

		IPredicateRule[] result= new IPredicateRule[rules.size()];
		rules.toArray(result);
		setPredicateRules(result);
	}
}
