/*
 * This file is part of RML Development Tooling.
 *
 * Copyright (c) 2006, Adrian Pop, adrpo@ida.liu.se
 *
 * @author Adrian Pop, adrpo@ida.liu.se
 */
package org.pelab.rml;

import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.plugin.*;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.resource.ImageDescriptor;
import org.osgi.framework.BundleContext;
import org.pelab.rml.views.RMLConsoleView;

import java.util.*;


public class RMLPlugin extends AbstractUIPlugin {
	//The shared instance.
	private static RMLPlugin plugin;
	//Resource bundle.
	private ResourceBundle resourceBundle;
	public static final String PLUGIN_ID = "org.pelab.rml.editor";
	
	/**
	 * The constructor.
	 */
	public RMLPlugin() {
		super();
		plugin = this;
		try {
			resourceBundle = ResourceBundle.getBundle("org.pelab.rml.RMLPluginMessages");
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */
	public static RMLPlugin getDefault() {
		return plugin;
	}

	/**
	 * Returns the string from the plugin's resource bundle,
	 * or 'key' if not found.
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = RMLPlugin.getDefault().getResourceBundle();
		try {
			return (bundle != null) ? bundle.getString(key) : key;
		} catch (MissingResourceException e) {
			return key;
		}
	}

	/**
	 * Returns the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		return resourceBundle;
	}
	
	/**
	 * Returns an image descriptor for the image file at the given
	 * plug-in relative path.
	 *
	 * @param path the path
	 * @return the image descriptor
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return AbstractUIPlugin.imageDescriptorFromPlugin("RDT", path);
	}
	
	
    public static RMLConsoleView getRMLConsole()
    {
		try {
			IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
			RMLConsoleView console = (RMLConsoleView)page.findView(RMLConsoleView.CONSOLE_ID);
			//boolean show = RMLPlugin.getDefault().getPreferenceStore().getBoolean(RMLPreferencePage.SHOW_OUTPUT_IN_CONSOLE);			
			if (console!=null) 
			{
				return console;
			} 
			else  
			{
				page.showView(RMLConsoleView.CONSOLE_ID);
				console = (RMLConsoleView)page.findView(RMLConsoleView.CONSOLE_ID);			
				return console;
			}
		} catch (PartInitException e) {
			e.printStackTrace();
			RMLPlugin.getDefault().getLog().log(
				new Status(
					IStatus.ERROR,
					RMLPlugin.PLUGIN_ID,
					0,
					RMLPlugin.getResourceString("CompilerAction.consoleViewOpeningProblem"),
					e));
			return null;
		}    	
    }	
}
