/*
 * (c) Copyright Adrian Pop, adrpo@ida.liu.se, 2006-02-21
 * All Rights Reserved.
 */
package org.pelab.rml.editor;


import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.texteditor.BasicTextEditorActionContributor;
import org.eclipse.ui.texteditor.ITextEditor;
import org.eclipse.ui.texteditor.RetargetTextEditorAction;

import org.pelab.rml.RMLPlugin;


/**
 * Contributes interesting RML actions to the desktop's Edit menu and
 * the toolbar.
 */
public class RMLActionContributor extends BasicTextEditorActionContributor {

	protected RetargetTextEditorAction contentAssistProposalAction;
	protected RMLCompilerAction compilerAction;

	/**
	 * Default constructor.
	 */
	public RMLActionContributor() {
		super();

		contentAssistProposalAction= new RetargetTextEditorAction(RMLPlugin.getDefault().getResourceBundle(), "ContentAssistProposal."); 
		compilerAction = RMLCompilerAction.getInstance();
	}
	
	/* (non-Javadoc)
	 * Method declared on EditorActionBarContributor
	 */
	public void contributeToMenu(IMenuManager menuManager) {
		super.contributeToMenu(menuManager);
		IMenuManager editMenu = menuManager.findMenuUsingPath(IWorkbenchActionConstants.M_EDIT);
		if (editMenu != null) {
			editMenu.add(new Separator());
			editMenu.add(contentAssistProposalAction);
		}
	}
	
	/* (non-Javadoc)
	 * Method declared on EditorActionBarContributor
	 */
	public void contributeToToolBar(IToolBarManager toolBarManager) {
		super.contributeToToolBar(toolBarManager);
		toolBarManager.add(new Separator());
		toolBarManager.add(compilerAction);
	}
	
	/* (non-Javadoc)
	 * Method declared on EditorActionBarContributor
	 */
	public void setActiveEditor(IEditorPart part) {
		super.setActiveEditor(part);

		ITextEditor editor= null;
		if (part instanceof ITextEditor)
			editor= (ITextEditor) part;

		contentAssistProposalAction.setAction(getAction(editor, "ContentAssistProposal")); 
		
		compilerAction.setEditor(editor);
		compilerAction.update();
	}
}
