/*
 * (c) Copyright Adrian Pop, adrpo@ida.liu.se, 2006-02-21
 * All Rights Reserved.
 */
package org.pelab.rml.editor;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IDocumentPartitioner;
import org.eclipse.jface.text.rules.FastPartitioner;
import org.eclipse.ui.editors.text.FileDocumentProvider;
//import org.eclipse.ui.editors.text.ForwardingDocumentProvider;
//import org.eclipse.ui.editors.text.TextFileDocumentProvider;

import org.pelab.rml.editor.rml.RMLPartitionScanner;

/** 
 * The RMLDocumentProvider provides the IDocuments used by c sharp editors.
 */

public class RMLDocumentProvider extends FileDocumentProvider {

	public static final String ID = RMLDocumentProvider.class.getName();
	private final static String[] TYPES = 
		new String[] 
		  { 
			RMLPartitionScanner.RML_DOC, 
			RMLPartitionScanner.RML_MULTILINE_COMMENT 
		  };

	private static RMLPartitionScanner scanner = null;

	public RMLDocumentProvider() {
		super();
	}
	
	/* (non-Javadoc)
	 * Method declared on AbstractDocumentProvider
	 */
	 protected IDocument createDocument(Object element) throws CoreException {
		IDocument document = super.createDocument(element);
		if (document != null) {
			IDocumentPartitioner partitioner = createRMLPartitioner();
			partitioner.connect(document);
			document.setDocumentPartitioner(partitioner);
		}
		return document;
	}
	
	/**
	 * Return a partitioner for .rml files.
	 */
	 private FastPartitioner createRMLPartitioner() {
		return new FastPartitioner(getRMLPartitionScanner(), TYPES);
	}
	
	/**
	 * Return a scanner for creating c sharp partitions.
	 */
	 private RMLPartitionScanner getRMLPartitionScanner() {
		if (scanner == null)
			scanner = new RMLPartitionScanner();
		return scanner;
	}
}
